@@ -17,6 +17,9 @@
 # limitations under the License.
 #
 
+require 'ruby27_fix_uri'
+require 'kramdown-parser-gfm'
+
 set :markdown_engine, :kramdown
 # rubocop:disable Layout/HashAlignment
 set(
@@ -106,11 +109,12 @@ RELEASEDOCMAKER = File.absolute_path('../releasedocmaker/src/main/python/release
 def releasenotes(output, version)
   # TODO: check jira for last update to the version and compare to source
   #       file timestamp
+  puts("Calling releasenotes #{version} @ #{output}")
   `(cd #{output} && #{RELEASEDOCMAKER} --project=YETUS --version=#{version} \
-                                       --projecttitle="Apache Yetus" \
-                                       --dirversions --empty \
-                                       --extension=.html.md \
-                                       --usetoday --license --lint=all)`
+    --projecttitle="Apache Yetus" \
+    --dirversions --empty \
+    --extension=.html.md \
+    --usetoday --license --lint=all)`
   errmsg = $stderr
   return if $CHILD_STATUS.exitstatus.zero?
 
@@ -118,52 +122,25 @@ def releasenotes(output, version)
   abort("releasedocmaker failed to generate release notes for #{version}.")
 end
 
-GITREPO = 'https://github.com/apache/yetus.git'
-
-def build_release_docs(output, version) # rubocop:disable Metrics/AbcSize, Metrics/MethodLength
+def build_release_docs(output, version)
   # TODO: get the version date from jira and do an up to date check instead of building each time.
   puts "Building docs for release #{version}"
   puts "\tcleaning up output directories in #{output}"
   FileUtils.rm_rf("#{output}/build-#{version}", secure: true)
   FileUtils.rm_rf("#{output}/#{version}", secure: true)
-  if version =~ /^0.[0-8]\./
-    puts "\tcloning from tag."
-    `(cd "#{output}" && \
-      git clone --depth 1 --branch "rel/#{version}" --single-branch -- \
-          "#{GITREPO}" "build-#{version}" \
-     ) >"#{output}/#{version}_git_checkout.log" 2>&1`
-    abort("building docs failed to for #{version}.") unless $CHILD_STATUS.exitstatus.zero?
-    puts "\tsetting up markdown docs"
-    FileUtils.mkdir "#{output}/#{version}"
-    FileUtils.mv(
-      Dir.glob("#{output}/build-#{version}/asf-site-src/source/documentation/in-progress/*.md*"),
-      "#{output}/#{version}/"
-    )
-    FileUtils.mv(
-      "#{output}/build-#{version}/asf-site-src/source/documentation/in-progress.html.md",
-      "#{output}/#{version}.html.md"
-    )
-    FileUtils.mkdir "#{output}/#{version}/precommit-apidocs"
-    precommit_shelldocs(
-      "#{output}/#{version}/precommit-apidocs",
-      "#{output}/build-#{version}/precommit"
-    )
-    puts "\tgenerating javadocs"
-    `(cd "#{output}/build-#{version}/audience-annotations-component" && mvn -DskipTests -Pinclude-jdiff-module javadoc:aggregate) >"#{output}/#{version}_mvn.log" 2>&1` # rubocop:disable Layout/LineLength
-    unless $CHILD_STATUS.exitstatus.zero?
-      puts "\tgenerating javadocs failed. maybe maven isn't installed? look in #{output}/#{version}_mvn.log" # rubocop:disable Layout/LineLength
-    end
-  else
-    puts "Downloading and extracting #{version} from ASF archives"
-    `(cd  #{output} \
-      && mkdir -p build-#{version} \
-      && curl --fail --location --output site-#{version}.tar.gz \
-        https://archive.apache.org/dist/yetus/#{version}/apache-yetus-#{version}-site.tar.gz \
-      && tar -C build-#{version} \
-         --strip-components 3 -xzpf site-#{version}.tar.gz \
-        apache-yetus-#{version}-site/documentation/in-progress/ \
+
+  puts "Downloading and extracting #{version} from ASF archives"
+  `(cd #{output} \
+    && mkdir -p build-#{version} \
+    && curl --fail --location --output site-#{version}.tar.gz \
+    https://archive.apache.org/dist/yetus/#{version}/apache-yetus-#{version}-site.tar.gz \
+    && tar -C build-#{version} \
+    --strip-components 3 -xzpf site-#{version}.tar.gz \
+    apache-yetus-#{version}-site/documentation/in-progress/ \
     )`
-  end
+  puts "Removing #{output}/build-#{version}/CHANGELOG"
+  FileUtils.rm_rf("#{output}/build-#{version}/CHANGELOG", secure: true)
+  FileUtils.rm_rf("#{output}/build-#{version}/RELEASENOTES", secure: true)
 end
 
 def precommit_shelldocs(apidocs_dir, source_dir)
@@ -174,7 +151,7 @@ def precommit_shelldocs(apidocs_dir, source_dir)
   # primary API
   shelldocs("#{apidocs_dir}/test-patch.html.md", ["#{source_dir}/test-patch.sh"])
   # plugins API
-  shelldocs("#{apidocs_dir}/plugins.html.md", Dir.glob("#{source_dir}/test-patch.d/*.sh"))
+  shelldocs("#{apidocs_dir}/plugins.html.md", Dir.glob("#{source_dir}/plugins.d/*.sh"))
 end
 
 # Add in apidocs rendered by other parts of the repo
@@ -191,7 +168,7 @@ after_configuration do # rubocop:disable Metrics/BlockLength
     end
   end
 
-  # For Audiene Annotations we just rely on having made javadocs with Maven
+  # For Audience Annotations we just rely on having made javadocs with Maven
   sitemap.register_resource_list_manipulator(
     :audience_annotations,
     ApiDocs.new(
@@ -204,42 +181,31 @@ after_configuration do # rubocop:disable Metrics/BlockLength
 
   # For Precommit we regenerate source files so they can be rendered.
   # we rely on a symlink. to avoid an error from the file watcher, our target
-  # has to be outside of hte asf-site-src directory.
+  # has to be outside of the asf-site-src directory.
   # TODO when we can, update to middleman 4 so we can use multiple source dirs
   # instead of symlinks
-  FileUtils.mkdir_p 'target/in-progress/precommit-apidocs/'
-  precommit_shelldocs('target/in-progress/precommit-apidocs/', '../precommit/src/main/shell')
+  FileUtils.mkdir_p 'target/in-progress/precommit/apidocs/'
+  precommit_shelldocs('target/in-progress/precommit/apidocs/', '../precommit/src/main/shell')
   # stitch the javadoc in place
   app.data.versions.releases&.each do |release|
     build_release_docs('target', release)
     releasenotes('target', release)
-    if release =~ /^0.[0-8]\./
-      # stitch the javadoc in place
-      # rubocop:disable Layout/LineLength
-      sitemap.register_resource_list_manipulator(
-        "#{release}_javadocs".to_sym,
-        ApiDocs.new(
-          sitemap,
-          "documentation/#{release}/audience-annotations-apidocs",
-          File.expand_path("target/build-#{release}/audience-annotations-component/target/site/apidocs", # rubocop:disable Layout/LineLength
-                           File.dirname(__FILE__))
-        )
+    sitemap.register_resource_list_manipulator(
+      "#{release}_javadocs".to_sym,
+      ApiDocs.new(
+        sitemap,
+        "documentation/#{release}",
+        File.expand_path("target/build-#{release}",
+                         File.dirname(__FILE__))
       )
-      # rubocop:enable Layout/LineLength
-    else
-      sitemap.register_resource_list_manipulator(
-        "#{release}_javadocs".to_sym,
-        ApiDocs.new(
-          sitemap,
-          "documentation/#{release}",
-          File.expand_path("target/build-#{release}",
-                           File.dirname(__FILE__))
-        )
-      )
-    end
+    )
   end
 end
 
 after_build do
   File.rename 'target/site/.htaccess.apache', 'target/site/.htaccess'
+  File.rename(
+    'target/site/documentation/in-progress/precommit/apidocs-index/index.html',
+    'target/site/documentation/in-progress/precommit/apidocs/index.html'
+  )
 end
