@@ -44,7 +44,10 @@ function common_defaults
   OSTYPE=$(uname -s)
   #shellcheck disable=SC2034
   PATCH_BRANCH=""
-  PATCH_BRANCH_DEFAULT="master"
+
+  # This will get automatically determined when possible
+  # later if this is still empty after various initializations
+  PATCH_BRANCH_DEFAULT=""
   #shellcheck disable=SC2034
   PATCH_DRYRUNMODE=false
   PATCH_DIR=/tmp
@@ -207,8 +210,14 @@ function common_args
       ;;
       --project=*)
         delete_parameter "${i}"
+        #shellcheck disable=SC2034
         PROJECT_NAME=${i#*=}
       ;;
+      --report-unknown-options=*)
+        delete_parameter "${i}"
+        #shellcheck disable=SC2034
+        REPORT_UNKNOWN_OPTIONS=${i#*=}
+      ;;
       --rsync-cmd=*)
         delete_parameter "${i}"
         RSYNC=${i#*=}
@@ -275,6 +284,21 @@ function common_args
     yetus_error "ERROR: ${GIT} v1.7.3 or higher is required (found ${version})."
     exit 1
   fi
+
+  # we need absolute dir for ${BASEDIR}
+  if ! cd "${STARTINGDIR}"; then
+    yetus_error "ERROR: Launch directory disappeared?!?"
+    cleanup_and_exit 1
+  fi
+  BASEDIR=$(yetus_abs "${BASEDIR}")
+
+  if [[ ! -d "${BASEDIR}" ]]; then
+    yetus_error "ERROR: --basedir is not a directory."
+    cleanup_and_exit 1
+  fi
+
+  PERSONALITY="${BASEDIR}/.yetus/personality.sh"
+  USER_PLUGIN_DIR="${BASEDIR}/.yetus/plugins.d"
 }
 
 ## @description  List all installed plug-ins, regardless of whether
@@ -536,7 +560,7 @@ function delete_build_tool
   yetus_del_array_element BUILDTOOLS "${1}"
 }
 
-## @description  Import content from test-patch.d and optionally
+## @description  Import content from plugins.d and optionally
 ## @description  from user provided plugin directory
 ## @audience     private
 ## @stability    evolving
@@ -547,37 +571,28 @@ function importplugins
   local plugin
   local files=()
 
-  #BUG: this will break horribly if there are spaces in the paths. :(
+  #BUG: this will break horribly if there are spaces in the file names. :(
 
   if [[ ${LOAD_SYSTEM_PLUGINS} == "true" ]]; then
-    if [[ -d "${BINDIR}/test-patch.d" ]]; then
-      #shellcheck disable=SC2206
-      files=(${BINDIR}/test-patch.d/*.sh)
+    if [[ -d "${BINDIR}/plugins.d" ]]; then
+      files=("${BINDIR}/plugins.d"/*.sh)
     fi
   fi
 
-  if [[ -n "${USER_PLUGIN_DIR}" && -d "${USER_PLUGIN_DIR}" ]]; then
+  if [[ -d "${USER_PLUGIN_DIR}" ]]; then
     yetus_debug "Loading user provided plugins from ${USER_PLUGIN_DIR}"
-    #shellcheck disable=SC2206
-    files+=(${USER_PLUGIN_DIR}/*.sh)
+    files+=("${USER_PLUGIN_DIR}"/*.sh)
   fi
 
-  if [[ -n ${PERSONALITY} && ! -f ${PERSONALITY} ]]; then
-    yetus_error "ERROR: Can't find ${PERSONALITY} to import."
-    unset PERSONALITY
-  fi
-
-  if [[ -z ${PERSONALITY}
-      && -f "${BINDIR}/personality/${PROJECT_NAME}.sh"
-      && ${LOAD_SYSTEM_PLUGINS} = "true" ]]; then
-    yetus_debug "Using project personality."
-    PERSONALITY="${BINDIR}/personality/${PROJECT_NAME}.sh"
-  fi
-
-  if [[ -n ${PERSONALITY} && -f ${PERSONALITY} ]]; then
+  if [[ -f ${PERSONALITY} ]]; then
     yetus_debug "Importing ${PERSONALITY}"
     # shellcheck disable=SC1090
-    . "${PERSONALITY}"
+    files+=("${PERSONALITY}")
+  else
+    if [[ "${PERSONALITY}" != "${BASEDIR}/.yetus/personality.sh" ]]; then
+      yetus_error "ERROR: ${PERSONALITY} does not exist."
+      exit 1
+    fi
   fi
 
   for i in "${files[@]}"; do
@@ -588,6 +603,7 @@ function importplugins
     fi
   done
 
+  # activate any replacement tests
   for i in "${TESTTYPES[@]}"; do
     if declare -f "${i}_deprecate_test_type" >/dev/null; then
       "${i}_deprecate_test_type"
@@ -726,9 +742,9 @@ function set_yetus_version
     VERSION=$(cat "${BINDIR}/VERSION")
   elif [[ -f "${BINDIR}/../../../pom.xml" ]]; then
     # this way we have no dependency on Maven being installed
-    VERSION=$(${GREP} "<version>" "${BINDIR}/../../../pom.xml" 2>/dev/null \
+    VERSION=$("${GREP}" "<version>" "${BINDIR}/../../../pom.xml" 2>/dev/null \
       | head -1 \
-      | ${SED}  -e 's|^ *<version>||' -e 's|</version>.*$||' 2>/dev/null)
+      | "${SED}"  -e 's|^ *<version>||' -e 's|</version>.*$||' 2>/dev/null)
   fi
 }
 
@@ -801,12 +817,13 @@ function guess_build_tool
 ## @param        module
 function module_file_fragment
 {
-  local mod=$1
-  if [[ ${mod} = \. ]]; then
+  declare mod
+
+  if [[ ${1} = \. ]]; then
     echo root
   else
-    #shellcheck disable=SC1003
-    echo "$1" | tr '/' '_' | tr '\\' '_'
+    mod=${1//\//_}
+    echo "${mod//\\/_}"
   fi
 }
 
@@ -843,7 +860,7 @@ function generate_stack
   exit 1
 }
 
-## @description  remove entries from paramater tracker
+## @description  remove entries from parameter tracker
 ## @audience     public
 ## @stability    stable
 ## @replaceable  no
